@charset "UTF-8";
:root{
  --wp-admin-theme-color:#007cba;
  --wp-admin-theme-color--rgb:0, 124, 186;
  --wp-admin-theme-color-darker-10:#006ba1;
  --wp-admin-theme-color-darker-10--rgb:0, 107, 161;
  --wp-admin-theme-color-darker-20:#005a87;
  --wp-admin-theme-color-darker-20--rgb:0, 90, 135;
  --wp-admin-border-width-focus:2px;
  --wp-block-synced-color:#7a00df;
  --wp-block-synced-color--rgb:122, 0, 223;
  --wp-bound-block-color:var(--wp-block-synced-color);
}
@media (min-resolution:192dpi){
  :root{
    --wp-admin-border-width-focus:1.5px;
  }
}

.dataviews-wrapper{
  box-sizing:border-box;
  container:dataviews-wrapper/inline-size;
  display:flex;
  flex-direction:column;
  font-size:13px;
  height:100%;
  line-height:1.4;
  overflow:auto;
  scroll-padding-bottom:64px;
}

.dataviews-filters__container,.dataviews__view-actions{
  box-sizing:border-box;
  flex-shrink:0;
  left:0;
  padding:16px 48px;
  position:sticky;
}
@media not (prefers-reduced-motion){
  .dataviews-filters__container,.dataviews__view-actions{
    transition:padding .1s ease-out;
  }
}

.dataviews-loading,.dataviews-no-results{
  align-items:center;
  display:flex;
  flex-grow:1;
  justify-content:center;
  padding:0 48px;
}
@media not (prefers-reduced-motion){
  .dataviews-loading,.dataviews-no-results{
    transition:padding .1s ease-out;
  }
}

@container (max-width: 430px){
  .dataviews-filters__container,.dataviews__view-actions{
    padding:12px 24px;
  }
  .dataviews-loading,.dataviews-no-results{
    padding-left:24px;
    padding-right:24px;
  }
}
.dataviews-title-field{
  font-size:13px;
  font-weight:500;
  width:100%;
}
.dataviews-title-field,.dataviews-title-field a{
  color:#2f2f2f;
  text-overflow:ellipsis;
  white-space:nowrap;
}
.dataviews-title-field a{
  display:block;
  flex-grow:0;
  overflow:hidden;
  text-decoration:none;
}
.dataviews-title-field a:hover{
  color:var(--wp-admin-theme-color);
}
.dataviews-title-field a:focus{
  border-radius:2px;
  box-shadow:0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color, #007cba);
  color:var(--wp-admin-theme-color--rgb);
}
.dataviews-title-field button.components-button.is-link{
  color:#1e1e1e;
  display:block;
  font-weight:inherit;
  overflow:hidden;
  text-decoration:none;
  text-overflow:ellipsis;
  white-space:nowrap;
  width:100%;
}
.dataviews-title-field button.components-button.is-link:hover{
  color:var(--wp-admin-theme-color);
}

.dataviews-title-field--clickable{
  color:#2f2f2f;
  cursor:pointer;
}
.dataviews-title-field--clickable:hover{
  color:var(--wp-admin-theme-color);
}
.dataviews-title-field--clickable:focus{
  border-radius:2px;
  box-shadow:0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color, #007cba);
  color:var(--wp-admin-theme-color--rgb);
}

.dataviews-bulk-actions-footer__item-count{
  color:#1e1e1e;
  font-size:11px;
  font-weight:500;
  text-transform:uppercase;
}

.dataviews-bulk-actions-footer__container{
  margin-right:auto;
  min-height:32px;
}

.dataviews-filters__button{
  position:relative;
}

.dataviews-filters__container{
  padding-top:0;
}

.dataviews-filters__reset-button.dataviews-filters__reset-button[aria-disabled=true],.dataviews-filters__reset-button.dataviews-filters__reset-button[aria-disabled=true]:hover{
  opacity:0;
}
.dataviews-filters__reset-button.dataviews-filters__reset-button[aria-disabled=true]:focus{
  opacity:1;
}

.dataviews-filters__summary-popover{
  font-size:13px;
  line-height:1.4;
}
.dataviews-filters__summary-popover .components-popover__content{
  border-radius:4px;
  width:230px;
}
.dataviews-filters__summary-popover.components-dropdown__content .components-popover__content{
  padding:0;
}

.dataviews-filters__summary-operators-container{
  padding:8px 8px 0;
}
.dataviews-filters__summary-operators-container:has(+.dataviews-filters__search-widget-listbox){
  border-bottom:1px solid #e0e0e0;
  padding-bottom:8px;
}
.dataviews-filters__summary-operators-container:empty{
  display:none;
}
.dataviews-filters__summary-operators-container .dataviews-filters__summary-operators-filter-name{
  color:#757575;
}

.dataviews-filters__summary-chip-container{
  position:relative;
  white-space:pre-wrap;
}
.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip{
  align-items:center;
  background:#f0f0f0;
  border:1px solid #0000;
  border-radius:16px;
  box-sizing:border-box;
  color:#2f2f2f;
  cursor:pointer;
  display:flex;
  min-height:32px;
  padding:4px 12px;
  position:relative;
}
.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip.has-reset{
  padding-inline-end:28px;
}
.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip:focus-visible,.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip:hover,.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip[aria-expanded=true]{
  background:#e0e0e0;
  color:#1e1e1e;
}
.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip.has-values{
  background:rgba(var(--wp-admin-theme-color--rgb), .04);
  color:var(--wp-admin-theme-color);
}
.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip.has-values:hover,.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip.has-values[aria-expanded=true]{
  background:rgba(var(--wp-admin-theme-color--rgb), .12);
}
.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip:focus-visible{
  box-shadow:0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color);
  outline:none;
}
.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip .dataviews-filters-__summary-filter-text-name{
  font-weight:500;
}
.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip-remove{
  align-items:center;
  background:#0000;
  border:0;
  border-radius:50%;
  cursor:pointer;
  display:flex;
  height:24px;
  justify-content:center;
  padding:0;
  position:absolute;
  right:4px;
  top:50%;
  transform:translateY(-50%);
  width:24px;
}
.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip-remove svg{
  fill:#757575;
}
.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip-remove:focus,.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip-remove:hover{
  background:#e0e0e0;
}
.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip-remove:focus svg,.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip-remove:hover svg{
  fill:#1e1e1e;
}
.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip-remove.has-values svg{
  fill:var(--wp-admin-theme-color);
}
.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip-remove.has-values:hover{
  background:rgba(var(--wp-admin-theme-color--rgb), .08);
}
.dataviews-filters__summary-chip-container .dataviews-filters__summary-chip-remove:focus-visible{
  box-shadow:0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color);
  outline:none;
}

.dataviews-filters__search-widget-filter-combobox-list{
  border-top:1px solid #e0e0e0;
  max-height:184px;
  overflow:auto;
  padding:4px;
}
.dataviews-filters__search-widget-filter-combobox-list .dataviews-filters__search-widget-filter-combobox-item-value [data-user-value]{
  font-weight:600;
}

.dataviews-filters__search-widget-listbox{
  overflow:auto;
  padding:4px;
}

.dataviews-filters__search-widget-listitem{
  align-items:center;
  border-radius:2px;
  box-sizing:border-box;
  cursor:default;
  display:flex;
  gap:8px;
  margin-block-end:2px;
  padding:8px 12px;
}
.dataviews-filters__search-widget-listitem:last-child{
  margin-block-end:0;
}
.dataviews-filters__search-widget-listitem:focus,.dataviews-filters__search-widget-listitem:hover,.dataviews-filters__search-widget-listitem[data-active-item]{
  background-color:var(--wp-admin-theme-color);
  color:#fff;
}
.dataviews-filters__search-widget-listitem:focus .dataviews-filters__search-widget-listitem-check,.dataviews-filters__search-widget-listitem:hover .dataviews-filters__search-widget-listitem-check,.dataviews-filters__search-widget-listitem[data-active-item] .dataviews-filters__search-widget-listitem-check{
  fill:#fff;
}
.dataviews-filters__search-widget-listitem:focus .dataviews-filters__search-widget-listitem-description,.dataviews-filters__search-widget-listitem:hover .dataviews-filters__search-widget-listitem-description,.dataviews-filters__search-widget-listitem[data-active-item] .dataviews-filters__search-widget-listitem-description{
  color:#fff;
}
.dataviews-filters__search-widget-listitem .dataviews-filters__search-widget-listitem-check{
  flex-shrink:0;
  height:24px;
  width:24px;
}
.dataviews-filters__search-widget-listitem .dataviews-filters__search-widget-listitem-description{
  color:#757575;
  display:block;
  font-size:12px;
  line-height:16px;
  overflow:hidden;
  text-overflow:ellipsis;
}

.dataviews-filters__search-widget-filter-combobox__wrapper{
  padding:8px;
  position:relative;
}
.dataviews-filters__search-widget-filter-combobox__wrapper .dataviews-filters__search-widget-filter-combobox__input{
  background:#f0f0f0;
  border:none;
  border-radius:2px;
  box-shadow:0 0 0 #0000;
  display:block;
  font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen-Sans,Ubuntu,Cantarell,Helvetica Neue,sans-serif;
  font-size:16px;
  height:32px;
  line-height:normal;
  margin-left:0;
  margin-right:0;
  padding:0 32px 0 8px;
  width:100%;
}
@media not (prefers-reduced-motion){
  .dataviews-filters__search-widget-filter-combobox__wrapper .dataviews-filters__search-widget-filter-combobox__input{
    transition:box-shadow .1s linear;
  }
}
@media (min-width:600px){
  .dataviews-filters__search-widget-filter-combobox__wrapper .dataviews-filters__search-widget-filter-combobox__input{
    font-size:13px;
    line-height:normal;
  }
}
.dataviews-filters__search-widget-filter-combobox__wrapper .dataviews-filters__search-widget-filter-combobox__input:focus{
  border-color:var(--wp-admin-theme-color);
  box-shadow:0 0 0 .5px var(--wp-admin-theme-color);
  outline:2px solid #0000;
}
.dataviews-filters__search-widget-filter-combobox__wrapper .dataviews-filters__search-widget-filter-combobox__input::-webkit-input-placeholder{
  color:#1e1e1e9e;
}
.dataviews-filters__search-widget-filter-combobox__wrapper .dataviews-filters__search-widget-filter-combobox__input::-moz-placeholder{
  color:#1e1e1e9e;
}
.dataviews-filters__search-widget-filter-combobox__wrapper .dataviews-filters__search-widget-filter-combobox__input:-ms-input-placeholder{
  color:#1e1e1e9e;
}
@media (min-width:600px){
  .dataviews-filters__search-widget-filter-combobox__wrapper .dataviews-filters__search-widget-filter-combobox__input{
    font-size:13px;
  }
}
.dataviews-filters__search-widget-filter-combobox__wrapper .dataviews-filters__search-widget-filter-combobox__input:focus{
  background:#fff;
  box-shadow:inset 0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color);
}
.dataviews-filters__search-widget-filter-combobox__wrapper .dataviews-filters__search-widget-filter-combobox__input::placeholder{
  color:#757575;
}
.dataviews-filters__search-widget-filter-combobox__wrapper .dataviews-filters__search-widget-filter-combobox__input::-webkit-search-cancel-button,.dataviews-filters__search-widget-filter-combobox__wrapper .dataviews-filters__search-widget-filter-combobox__input::-webkit-search-decoration,.dataviews-filters__search-widget-filter-combobox__wrapper .dataviews-filters__search-widget-filter-combobox__input::-webkit-search-results-button,.dataviews-filters__search-widget-filter-combobox__wrapper .dataviews-filters__search-widget-filter-combobox__input::-webkit-search-results-decoration{
  -webkit-appearance:none;
}
.dataviews-filters__search-widget-filter-combobox__wrapper .dataviews-filters__search-widget-filter-combobox__icon{
  align-items:center;
  display:flex;
  justify-content:center;
  position:absolute;
  right:12px;
  top:50%;
  transform:translateY(-50%);
  width:24px;
}

.dataviews-filters__container-visibility-toggle{
  flex-shrink:0;
  position:relative;
}

.dataviews-filters-toggle__count{
  background:var(--wp-admin-theme-color, #3858e9);
  border-radius:8px;
  box-sizing:border-box;
  color:#fff;
  font-size:11px;
  height:16px;
  line-height:16px;
  min-width:16px;
  outline:var(--wp-admin-border-width-focus) solid #fff;
  padding:0 4px;
  position:absolute;
  right:0;
  text-align:center;
  top:0;
  transform:translate(50%, -50%);
}

.dataviews-search{
  width:fit-content;
}

.dataviews-footer{
  background-color:#fff;
  border-top:1px solid #f0f0f0;
  bottom:0;
  flex-shrink:0;
  left:0;
  padding:12px 48px;
  position:sticky;
  z-index:2;
}
@media not (prefers-reduced-motion){
  .dataviews-footer{
    transition:padding .1s ease-out;
  }
}

@container (max-width: 430px){
  .dataviews-footer{
    padding:12px 24px;
  }
}
@container (max-width: 560px){
  .dataviews-footer{
    flex-direction:column !important;
  }
  .dataviews-footer .dataviews-bulk-actions-footer__container{
    width:100%;
  }
  .dataviews-footer .dataviews-bulk-actions-footer__item-count{
    flex-grow:1;
  }
  .dataviews-footer .dataviews-pagination{
    justify-content:space-between;
    width:100%;
  }
}
.dataviews-pagination__page-select{
  font-size:11px;
  font-weight:500;
  text-transform:uppercase;
}
@media (min-width:600px){
  .dataviews-pagination__page-select .components-select-control__input{
    font-size:11px !important;
    font-weight:500;
  }
}

.dataviews-action-modal{
  z-index:1000001;
}

.dataviews-selection-checkbox{
  --checkbox-input-size:24px;
  flex-shrink:0;
  line-height:0;
}
@media (min-width:600px){
  .dataviews-selection-checkbox{
    --checkbox-input-size:16px;
  }
}
.dataviews-selection-checkbox .components-checkbox-control__input-container{
  margin:0;
}

.dataviews-view-config{
  container-type:inline-size;
  font-size:13px;
  line-height:1.4;
  width:320px;
}

.dataviews-config__popover.is-expanded .dataviews-config__popover-content-wrapper{
  height:100%;
  overflow-y:scroll;
}
.dataviews-config__popover.is-expanded .dataviews-config__popover-content-wrapper .dataviews-view-config{
  width:auto;
}

.dataviews-view-config__sort-direction .components-toggle-group-control-option-base{
  text-transform:uppercase;
}

.dataviews-settings-section__title.dataviews-settings-section__title{
  font-size:15px;
  line-height:24px;
}

.dataviews-settings-section__sidebar{
  grid-column:span 4;
}

.dataviews-settings-section__content,.dataviews-settings-section__content>*{
  grid-column:span 8;
}

.dataviews-settings-section__content .is-divided-in-two{
  display:contents;
}
.dataviews-settings-section__content .is-divided-in-two>*{
  grid-column:span 4;
}

.dataviews-settings-section:has(.dataviews-settings-section__content:empty){
  display:none;
}

@container (max-width: 500px){
  .dataviews-settings-section.dataviews-settings-section{
    grid-template-columns:repeat(2, 1fr);
  }
  .dataviews-settings-section.dataviews-settings-section .dataviews-settings-section__content,.dataviews-settings-section.dataviews-settings-section .dataviews-settings-section__sidebar{
    grid-column:span 2;
  }
}
.dataviews-field-control__field{
  height:32px;
}

.dataviews-field-control__actions{
  position:absolute;
  top:-9999em;
}

.dataviews-field-control__actions.dataviews-field-control__actions{
  gap:4px;
}

.dataviews-field-control__field.is-interacting .dataviews-field-control__actions,.dataviews-field-control__field:focus-within .dataviews-field-control__actions,.dataviews-field-control__field:hover .dataviews-field-control__actions{
  position:unset;
  top:unset;
}

.dataviews-field-control__icon{
  display:flex;
  width:24px;
}

.dataviews-field-control__label-sub-label-container{
  flex-grow:1;
}

.dataviews-field-control__label{
  display:block;
}

.dataviews-field-control__sub-label{
  color:#757575;
  font-size:11px;
  font-style:normal;
  margin-bottom:0;
  margin-top:8px;
}

.dataviews-view-grid{
  container-type:inline-size;
  grid-template-rows:max-content;
  margin-bottom:auto;
  padding:0 48px 24px;
}
@media not (prefers-reduced-motion){
  .dataviews-view-grid{
    transition:padding .1s ease-out;
  }
}
.dataviews-view-grid .dataviews-view-grid__card{
  height:100%;
  justify-content:flex-start;
  position:relative;
}
.dataviews-view-grid .dataviews-view-grid__card .dataviews-view-grid__title-actions{
  padding:8px 0 4px;
}
.dataviews-view-grid .dataviews-view-grid__card .dataviews-view-grid__title-field{
  align-items:center;
  display:flex;
  min-height:24px;
}
.dataviews-view-grid .dataviews-view-grid__card .dataviews-view-grid__title-field--clickable{
  width:fit-content;
}
.dataviews-view-grid .dataviews-view-grid__card.is-selected .dataviews-view-grid__fields .dataviews-view-grid__field .dataviews-view-grid__field-value{
  color:#1e1e1e;
}
.dataviews-view-grid .dataviews-view-grid__card .dataviews-view-grid__media:focus:after,.dataviews-view-grid .dataviews-view-grid__card.is-selected .dataviews-view-grid__media:after{
  background-color:rgba(var(--wp-admin-theme-color--rgb), .08);
}
.dataviews-view-grid .dataviews-view-grid__card.is-selected .dataviews-view-grid__media:after{
  box-shadow:inset 0 0 0 1px var(--wp-admin-theme-color);
}
.dataviews-view-grid .dataviews-view-grid__card .dataviews-view-grid__media:focus:after{
  box-shadow:inset 0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color);
}
.dataviews-view-grid .dataviews-view-grid__media{
  aspect-ratio:1/1;
  background-color:#f0f0f0;
  border-radius:4px;
  min-height:200px;
  position:relative;
  width:100%;
}
.dataviews-view-grid .dataviews-view-grid__media img{
  height:100%;
  object-fit:cover;
  width:100%;
}
.dataviews-view-grid .dataviews-view-grid__media:after{
  border-radius:4px;
  box-shadow:inset 0 0 0 1px #0000001a;
  content:"";
  height:100%;
  left:0;
  pointer-events:none;
  position:absolute;
  top:0;
  width:100%;
}
.dataviews-view-grid .dataviews-view-grid__fields{
  font-size:12px;
  line-height:16px;
  position:relative;
}
.dataviews-view-grid .dataviews-view-grid__fields:not(:empty){
  padding:0 0 12px;
}
.dataviews-view-grid .dataviews-view-grid__fields .dataviews-view-grid__field-value:not(:empty){
  line-height:20px;
  min-height:24px;
  padding-top:2px;
}
.dataviews-view-grid .dataviews-view-grid__fields .dataviews-view-grid__field{
  align-items:center;
  min-height:24px;
}
.dataviews-view-grid .dataviews-view-grid__fields .dataviews-view-grid__field .dataviews-view-grid__field-name{
  color:#757575;
  width:35%;
}
.dataviews-view-grid .dataviews-view-grid__fields .dataviews-view-grid__field .dataviews-view-grid__field-value{
  overflow:hidden;
  text-overflow:ellipsis;
  white-space:nowrap;
  width:65%;
}
.dataviews-view-grid .dataviews-view-grid__fields .dataviews-view-grid__field:not(:has(.dataviews-view-grid__field-value:not(:empty))){
  display:none;
}
.dataviews-view-grid .dataviews-view-grid__badge-fields:not(:empty){
  padding-bottom:12px;
}
@container (max-width: 480px){
  .dataviews-view-grid.dataviews-view-grid{
    grid-template-columns:repeat(1, minmax(0, 1fr));
    padding-left:24px;
    padding-right:24px;
  }
}
@container (min-width: 480px){
  .dataviews-view-grid.dataviews-view-grid{
    grid-template-columns:repeat(2, minmax(0, 1fr));
  }
}
@container (min-width: 780px){
  .dataviews-view-grid.dataviews-view-grid{
    grid-template-columns:repeat(3, minmax(0, 1fr));
  }
}
@container (min-width: 1140px){
  .dataviews-view-grid.dataviews-view-grid{
    grid-template-columns:repeat(4, minmax(0, 1fr));
  }
}
@container (min-width: 1520px){
  .dataviews-view-grid.dataviews-view-grid{
    grid-template-columns:repeat(5, minmax(0, 1fr));
  }
}

.dataviews-view-grid__field-value:empty,.dataviews-view-grid__field:empty{
  display:none;
}

.dataviews-view-grid__card .dataviews-selection-checkbox{
  left:8px;
  position:absolute;
  top:-9999em;
  z-index:1;
}

.dataviews-view-grid__card.is-selected .dataviews-selection-checkbox,.dataviews-view-grid__card:focus-within .dataviews-selection-checkbox,.dataviews-view-grid__card:hover .dataviews-selection-checkbox{
  top:8px;
}

.dataviews-view-grid__media--clickable{
  cursor:pointer;
}

div.dataviews-view-list{
  list-style-type:none;
}

.dataviews-view-list{
  margin:0 0 auto;
}
.dataviews-view-list div[role=row]{
  border-top:1px solid #f0f0f0;
  margin:0;
}
.dataviews-view-list div[role=row] .dataviews-view-list__item-wrapper{
  box-sizing:border-box;
  padding:16px 24px;
  position:relative;
}
.dataviews-view-list div[role=row] .dataviews-view-list__item-actions{
  flex:0;
  overflow:hidden;
}
.dataviews-view-list div[role=row] .dataviews-view-list__item-actions>div{
  height:24px;
}
.dataviews-view-list div[role=row] .dataviews-view-list__item-actions .components-button{
  opacity:0;
  position:relative;
  z-index:1;
}
.dataviews-view-list div[role=row]:where(.is-selected,.is-hovered,:focus-within) .dataviews-view-list__item-actions{
  flex-basis:min-content;
  overflow:unset;
  padding-inline-end:4px;
}
.dataviews-view-list div[role=row]:where(.is-selected,.is-hovered,:focus-within) .dataviews-view-list__item-actions .components-button{
  opacity:1;
}
.dataviews-view-list div[role=row].is-selected.is-selected,.dataviews-view-list div[role=row].is-selected.is-selected+div[role=row]{
  border-top:1px solid rgba(var(--wp-admin-theme-color--rgb), .12);
}
.dataviews-view-list div[role=row]:not(.is-selected) .dataviews-view-list__title-field{
  color:#1e1e1e;
}
.dataviews-view-list div[role=row]:not(.is-selected).is-hovered,.dataviews-view-list div[role=row]:not(.is-selected):focus-within,.dataviews-view-list div[role=row]:not(.is-selected):hover{
  background-color:#f8f8f8;
  color:var(--wp-admin-theme-color);
}
.dataviews-view-list div[role=row]:not(.is-selected).is-hovered .dataviews-view-list__fields,.dataviews-view-list div[role=row]:not(.is-selected).is-hovered .dataviews-view-list__title-field,.dataviews-view-list div[role=row]:not(.is-selected):focus-within .dataviews-view-list__fields,.dataviews-view-list div[role=row]:not(.is-selected):focus-within .dataviews-view-list__title-field,.dataviews-view-list div[role=row]:not(.is-selected):hover .dataviews-view-list__fields,.dataviews-view-list div[role=row]:not(.is-selected):hover .dataviews-view-list__title-field{
  color:var(--wp-admin-theme-color);
}
.dataviews-view-list div[role=row].is-selected .dataviews-view-list__item-wrapper,.dataviews-view-list div[role=row].is-selected:focus-within .dataviews-view-list__item-wrapper{
  background-color:rgba(var(--wp-admin-theme-color--rgb), .04);
  color:#1e1e1e;
}
.dataviews-view-list div[role=row].is-selected .dataviews-view-list__item-wrapper .dataviews-view-list__fields,.dataviews-view-list div[role=row].is-selected .dataviews-view-list__item-wrapper .dataviews-view-list__title-field,.dataviews-view-list div[role=row].is-selected:focus-within .dataviews-view-list__item-wrapper .dataviews-view-list__fields,.dataviews-view-list div[role=row].is-selected:focus-within .dataviews-view-list__item-wrapper .dataviews-view-list__title-field{
  color:var(--wp-admin-theme-color);
}
.dataviews-view-list .dataviews-view-list__item{
  appearance:none;
  background:none;
  border:none;
  cursor:pointer;
  inset:0;
  padding:0;
  position:absolute;
  scroll-margin:8px 0;
  z-index:1;
}
.dataviews-view-list .dataviews-view-list__item:focus-visible{
  outline:none;
}
.dataviews-view-list .dataviews-view-list__item:focus-visible:before{
  border-radius:2px;
  box-shadow:inset 0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color);
  content:"";
  inset:var(--wp-admin-border-width-focus);
  outline:2px solid #0000;
  position:absolute;
}
.dataviews-view-list .dataviews-view-list__title-field{
  flex:1;
  line-height:24px;
  min-height:24px;
  overflow:hidden;
}
.dataviews-view-list .dataviews-view-list__title-field:has(a,button){
  z-index:1;
}
.dataviews-view-list .dataviews-view-list__media-wrapper{
  background-color:#f0f0f0;
  border-radius:4px;
  flex-shrink:0;
  height:52px;
  overflow:hidden;
  position:relative;
  width:52px;
}
.dataviews-view-list .dataviews-view-list__media-wrapper img{
  height:100%;
  object-fit:cover;
  width:100%;
}
.dataviews-view-list .dataviews-view-list__media-wrapper:after{
  border-radius:4px;
  box-shadow:inset 0 0 0 1px #0000001a;
  content:"";
  height:100%;
  left:0;
  position:absolute;
  top:0;
  width:100%;
}
.dataviews-view-list .dataviews-view-list__field-wrapper{
  flex-grow:1;
  min-height:52px;
}
.dataviews-view-list .dataviews-view-list__fields{
  color:#757575;
  display:flex;
  flex-wrap:wrap;
  font-size:12px;
  gap:12px;
  row-gap:4px;
}
.dataviews-view-list .dataviews-view-list__fields .dataviews-view-list__field:has(.dataviews-view-list__field-value:empty),.dataviews-view-list .dataviews-view-list__fields:empty{
  display:none;
}
.dataviews-view-list .dataviews-view-list__fields .dataviews-view-list__field-value{
  align-items:center;
  display:flex;
  line-height:20px;
  min-height:24px;
}
.dataviews-view-list+.dataviews-pagination{
  justify-content:space-between;
}

.dataviews-view-table{
  border-collapse:collapse;
  border-color:inherit;
  color:#757575;
  margin-bottom:auto;
  position:relative;
  text-indent:0;
  width:100%;
}
.dataviews-view-table th{
  color:#1e1e1e;
  font-size:13px;
  font-weight:400;
  text-align:left;
}
.dataviews-view-table td,.dataviews-view-table th{
  padding:12px;
  white-space:nowrap;
}
.dataviews-view-table td.dataviews-view-table__actions-column,.dataviews-view-table th.dataviews-view-table__actions-column{
  text-align:right;
}
.dataviews-view-table td.dataviews-view-table__checkbox-column,.dataviews-view-table th.dataviews-view-table__checkbox-column{
  padding-right:0;
  width:1%;
}
.dataviews-view-table tr{
  border-top:1px solid #f0f0f0;
}
.dataviews-view-table tr .dataviews-view-table-header-button{
  gap:4px;
}
.dataviews-view-table tr td:first-child,.dataviews-view-table tr th:first-child{
  padding-left:48px;
}
.dataviews-view-table tr td:first-child .dataviews-view-table-header-button,.dataviews-view-table tr th:first-child .dataviews-view-table-header-button{
  margin-left:-8px;
}
.dataviews-view-table tr td:last-child,.dataviews-view-table tr th:last-child{
  padding-right:48px;
}
.dataviews-view-table tr:last-child{
  border-bottom:0;
}
.dataviews-view-table tr.is-hovered{
  background-color:#f8f8f8;
}
.dataviews-view-table tr .components-checkbox-control__input.components-checkbox-control__input{
  opacity:0;
}
.dataviews-view-table tr .components-checkbox-control__input.components-checkbox-control__input:checked,.dataviews-view-table tr .components-checkbox-control__input.components-checkbox-control__input:focus,.dataviews-view-table tr .components-checkbox-control__input.components-checkbox-control__input:indeterminate{
  opacity:1;
}
.dataviews-view-table tr .dataviews-item-actions .components-button:not(.dataviews-all-actions-button){
  opacity:0;
}
.dataviews-view-table tr.is-hovered .components-checkbox-control__input,.dataviews-view-table tr.is-hovered .dataviews-item-actions .components-button:not(.dataviews-all-actions-button),.dataviews-view-table tr:focus-within .components-checkbox-control__input,.dataviews-view-table tr:focus-within .dataviews-item-actions .components-button:not(.dataviews-all-actions-button),.dataviews-view-table tr:hover .components-checkbox-control__input,.dataviews-view-table tr:hover .dataviews-item-actions .components-button:not(.dataviews-all-actions-button){
  opacity:1;
}
@media (hover:none){
  .dataviews-view-table tr .components-checkbox-control__input.components-checkbox-control__input,.dataviews-view-table tr .dataviews-item-actions .components-button:not(.dataviews-all-actions-button){
    opacity:1;
  }
}
.dataviews-view-table tr.is-selected{
  background-color:rgba(var(--wp-admin-theme-color--rgb), .04);
  color:#757575;
}
.dataviews-view-table tr.is-selected,.dataviews-view-table tr.is-selected+tr{
  border-top:1px solid rgba(var(--wp-admin-theme-color--rgb), .12);
}
.dataviews-view-table tr.is-selected:hover{
  background-color:rgba(var(--wp-admin-theme-color--rgb), .08);
}
.dataviews-view-table thead{
  inset-block-start:0;
  position:sticky;
  z-index:1;
}
.dataviews-view-table thead tr{
  border:0;
}
.dataviews-view-table thead th{
  background-color:#fff;
  font-size:11px;
  font-weight:500;
  padding-bottom:8px;
  padding-left:12px;
  padding-top:8px;
  text-transform:uppercase;
}
.dataviews-view-table thead th:has(.dataviews-view-table-header-button):not(:first-child){
  padding-left:4px;
}
.dataviews-view-table tbody td{
  vertical-align:top;
}
.dataviews-view-table tbody .dataviews-view-table__cell-content-wrapper{
  align-items:center;
  display:flex;
  min-height:32px;
}
.dataviews-view-table tbody .components-v-stack>.dataviews-view-table__cell-content-wrapper:not(:first-child){
  min-height:0;
}
.dataviews-view-table .dataviews-view-table-header-button{
  font-size:11px;
  font-weight:500;
  padding:4px 8px;
  text-transform:uppercase;
}
.dataviews-view-table .dataviews-view-table-header-button:not(:hover){
  color:#1e1e1e;
}
.dataviews-view-table .dataviews-view-table-header-button span{
  speak:none;
}
.dataviews-view-table .dataviews-view-table-header-button span:empty{
  display:none;
}
.dataviews-view-table .dataviews-view-table-header{
  padding-left:4px;
}
.dataviews-view-table .dataviews-view-table__actions-column{
  width:1%;
}
.dataviews-view-table:has(tr.is-selected) .components-checkbox-control__input{
  opacity:1;
}
.dataviews-view-table.has-compact-density thead th:has(.dataviews-view-table-header-button):not(:first-child){
  padding-left:0;
}
.dataviews-view-table.has-compact-density td,.dataviews-view-table.has-compact-density th{
  padding:4px 8px;
}
.dataviews-view-table.has-comfortable-density td,.dataviews-view-table.has-comfortable-density th{
  padding:16px 12px;
}
.dataviews-view-table.has-comfortable-density td.dataviews-view-table__checkbox-column,.dataviews-view-table.has-comfortable-density th.dataviews-view-table__checkbox-column,.dataviews-view-table.has-compact-density td.dataviews-view-table__checkbox-column,.dataviews-view-table.has-compact-density th.dataviews-view-table__checkbox-column{
  padding-right:0;
}

@container (max-width: 430px){
  .dataviews-view-table tr td:first-child,.dataviews-view-table tr th:first-child{
    padding-left:24px;
  }
  .dataviews-view-table tr td:last-child,.dataviews-view-table tr th:last-child{
    padding-right:24px;
  }
}
.dataviews-view-table-selection-checkbox{
  --checkbox-input-size:24px;
}
@media (min-width:600px){
  .dataviews-view-table-selection-checkbox{
    --checkbox-input-size:16px;
  }
}

.dataviews-column-primary__media{
  max-width:60px;
}

.dataviews-controls__datetime{
  border:none;
  padding:0;
}

.dataforms-layouts-panel__field{
  align-items:flex-start !important;
  justify-content:flex-start !important;
  min-height:32px;
  width:100%;
}

.dataforms-layouts-panel__field-label{
  align-items:center;
  display:flex;
  flex-shrink:0;
  hyphens:auto;
  line-height:20px;
  min-height:32px;
  padding:6px 0;
  width:38%;
}

.dataforms-layouts-panel__field-control{
  align-items:center;
  display:flex;
  flex-grow:1;
  min-height:32px;
}
.dataforms-layouts-panel__field-control .components-button{
  max-width:100%;
  min-height:32px;
  text-align:left;
  text-wrap:balance;
  text-wrap:pretty;
  white-space:normal;
}
.dataforms-layouts-panel__field-control .components-dropdown{
  max-width:100%;
}

.dataforms-layouts-panel__field-dropdown .components-popover__content{
  min-width:320px;
  padding:16px;
}

.dataforms-layouts-panel__dropdown-header{
  margin-bottom:16px;
}

.components-popover.components-dropdown__content.dataforms-layouts-panel__field-dropdown{
  z-index:159990;
}

.dataforms-layouts-regular__field{
  align-items:flex-start !important;
  justify-content:flex-start !important;
  min-height:32px;
  width:100%;
}

.dataforms-layouts-regular__field .components-base-control__label{
  font-size:inherit;
  font-weight:400;
  text-transform:none;
}

.dataforms-layouts-regular__field-label{
  align-items:center;
  display:flex;
  flex-shrink:0;
  hyphens:auto;
  line-height:20px;
  min-height:32px;
  padding:6px 0;
  width:38%;
}

.dataforms-layouts-regular__field-control{
  align-items:center;
  display:flex;
  flex-grow:1;
  min-height:32px;
}

.edit-site-layout{
  color:#ccc;
  display:flex;
  flex-direction:column;
  height:100%;
}
.edit-site-layout,.edit-site-layout:not(.is-full-canvas) .editor-visual-editor{
  background:#1e1e1e;
}

.edit-site-layout__content{
  display:flex;
  flex-grow:1;
  height:100%;
}

.edit-site-layout__sidebar-region{
  flex-shrink:0;
  width:100vw;
  z-index:1;
}
@media (min-width:782px){
  .edit-site-layout__sidebar-region{
    width:300px;
  }
}
.edit-site-layout.is-full-canvas .edit-site-layout__sidebar-region{
  height:100vh;
  left:0;
  position:fixed !important;
  top:0;
}
.edit-site-layout__sidebar-region .edit-site-layout__sidebar{
  display:flex;
  flex-direction:column;
  height:100%;
}
.edit-site-layout__sidebar-region .resizable-editor__drag-handle{
  right:0;
}

.edit-site-layout__main{
  display:flex;
  flex-direction:column;
  flex-grow:1;
  overflow:hidden;
}

.edit-site-layout__mobile{
  display:flex;
  flex-direction:column;
  position:relative;
  width:100%;
  z-index:2;
}
.edit-site-layout__mobile .edit-site-sidebar__screen-wrapper{
  padding:0;
}
.edit-site-layout__mobile .edit-site-sidebar-navigation-screen__main{
  padding:0 12px;
}

.edit-site-layout__canvas-container{
  flex-grow:1;
  overflow:visible;
  position:relative;
  z-index:2;
}
.edit-site-layout__canvas-container.is-resizing:after{
  bottom:0;
  content:"";
  left:0;
  position:absolute;
  right:0;
  top:0;
  z-index:100;
}

.edit-site-layout__canvas{
  align-items:center;
  bottom:0;
  display:flex;
  justify-content:center;
  left:0;
  position:absolute;
  top:0;
  width:100%;
}
.edit-site-layout__canvas.is-right-aligned{
  justify-content:flex-end;
}
.edit-site-layout__canvas .edit-site-resizable-frame__inner{
  color:#1e1e1e;
}
@media (min-width:782px){
  .edit-site-layout__canvas{
    bottom:16px;
    top:16px;
    width:calc(100% - 16px);
  }
  .edit-site-layout__canvas .edit-site-resizable-frame__inner-content{
    box-shadow:0 1px 1px #00000008,0 1px 2px #00000005,0 3px 3px #00000005,0 4px 4px #00000003;
    overflow:hidden;
  }
}
@media (min-width:782px) and (not (prefers-reduced-motion)){
  .edit-site-layout__canvas .edit-site-resizable-frame__inner-content{
    transition:border-radius,box-shadow .4s;
  }
}
@media (min-width:782px){
  .edit-site-layout:not(.is-full-canvas) .edit-site-layout__canvas .edit-site-resizable-frame__inner-content{
    border-radius:8px;
  }
  .edit-site-layout__canvas .edit-site-resizable-frame__inner-content:hover{
    box-shadow:0 5px 15px #00000014,0 15px 27px #00000012,0 30px 36px #0000000a,0 50px 43px #00000005;
  }
}
.edit-site-layout.is-full-canvas .edit-site-layout__canvas{
  bottom:0;
  top:0;
  width:100%;
}

.edit-site-layout__canvas .interface-interface-skeleton,.edit-site-layout__mobile .interface-interface-skeleton,.edit-site-template-pages-preview .interface-interface-skeleton{
  min-height:100% !important;
  position:relative !important;
}

.edit-site-template-pages-preview{
  height:100%;
}
html.canvas-mode-edit-transition::view-transition-group(toggle){
  animation-delay:255ms;
}

@media (prefers-reduced-motion){
  ::view-transition-group(*),::view-transition-new(*),::view-transition-old(*){
    animation:none !important;
  }
}
.edit-site-layout.is-full-canvas .edit-site-layout__sidebar-region .edit-site-layout__view-mode-toggle{
  display:none;
}

.edit-site-layout__view-mode-toggle.components-button{
  view-transition-name:toggle;
  align-items:center;
  background:#1e1e1e;
  border-radius:0;
  color:#fff;
  display:flex;
  height:60px;
  justify-content:center;
  overflow:hidden;
  padding:0;
  position:relative;
  width:60px;
}
.edit-site-layout__view-mode-toggle.components-button:active,.edit-site-layout__view-mode-toggle.components-button:hover{
  color:#fff;
}
.edit-site-layout__view-mode-toggle.components-button:focus,.edit-site-layout__view-mode-toggle.components-button:focus-visible{
  box-shadow:0 0 0 3px #1e1e1e, 0 0 0 6px var(--wp-admin-theme-color);
  outline:4px solid #0000;
  outline-offset:4px;
}
.edit-site-layout__view-mode-toggle.components-button:before{
  border-radius:4px;
  bottom:9px;
  box-shadow:none;
  content:"";
  display:block;
  left:9px;
  position:absolute;
  right:9px;
  top:9px;
}
@media not (prefers-reduced-motion){
  .edit-site-layout__view-mode-toggle.components-button:before{
    transition:box-shadow .1s ease;
  }
}
.edit-site-layout__view-mode-toggle.components-button .edit-site-layout__view-mode-toggle-icon{
  align-items:center;
  display:flex;
  height:60px;
  justify-content:center;
  width:60px;
}

.edit-site-layout__actions{
  background:#fff;
  bottom:auto;
  color:#1e1e1e;
  left:auto;
  position:fixed !important;
  right:0;
  top:-9999em;
  width:280px;
  z-index:100000;
}
.edit-site-layout__actions:focus,.edit-site-layout__actions:focus-within{
  bottom:0;
  top:auto;
}
.edit-site-layout__actions.is-entity-save-view-open:focus,.edit-site-layout__actions.is-entity-save-view-open:focus-within{
  top:0;
}
@media (min-width:782px){
  .edit-site-layout__actions{
    border-left:1px solid #ddd;
  }
}

.edit-site-layout__area{
  box-shadow:0 1px 1px #00000008,0 1px 2px #00000005,0 3px 3px #00000005,0 4px 4px #00000003;
  flex-grow:1;
  margin:0;
  overflow:hidden;
}
@media (min-width:782px){
  .edit-site-layout__area{
    border-radius:8px;
    margin:16px 16px 16px 0;
  }
}

.edit-site .components-editor-notices__snackbar{
  bottom:16px;
  padding-left:16px;
  padding-right:16px;
  position:fixed;
  right:0;
}

.edit-site-page{
  background:#fff;
  color:#2f2f2f;
  container:edit-site-page/inline-size;
  height:100%;
}
@media not (prefers-reduced-motion){
  .edit-site-page{
    transition:width .2s ease-out;
  }
}

.edit-site-page-header{
  background:#fff;
  border-bottom:1px solid #f0f0f0;
  padding:16px 48px;
  position:sticky;
  top:0;
  z-index:2;
}
@media not (prefers-reduced-motion){
  .edit-site-page-header{
    transition:padding .1s ease-out;
  }
}
.edit-site-page-header .components-heading{
  color:#1e1e1e;
}
.edit-site-page-header .edit-site-page-header__page-title{
  min-height:40px;
}
.edit-site-page-header .edit-site-page-header__page-title .components-heading{
  flex-basis:0;
  flex-grow:1;
  white-space:nowrap;
}
.edit-site-page-header .edit-site-page-header__sub-title{
  margin-bottom:8px;
}

@container (max-width: 430px){
  .edit-site-page-header{
    padding:16px 24px;
  }
}
.edit-site-page-content{
  display:flex;
  flex-flow:column;
  height:100%;
  position:relative;
  z-index:1;
}

.edit-site-save-hub{
  border-top:1px solid #2f2f2f;
  color:#949494;
  flex-shrink:0;
  margin:0;
  padding:16px;
}

.edit-site-save-hub__button{
  color:inherit;
  justify-content:center;
  width:100%;
}
.edit-site-save-hub__button[aria-disabled=true]{
  opacity:1;
}
.edit-site-save-hub__button[aria-disabled=true]:hover{
  color:inherit;
}
.edit-site-save-hub__button:not(.is-primary).is-busy,.edit-site-save-hub__button:not(.is-primary).is-busy[aria-disabled=true]:hover{
  color:#1e1e1e;
}

@media (min-width:600px){
  .edit-site-save-panel__modal{
    width:600px;
  }
}

.edit-site-sidebar__content{
  contain:content;
  flex-grow:1;
  overflow-x:hidden;
  overflow-y:auto;
}

@keyframes _fwjws_slide-from-right{
  0%{
    opacity:0;
    transform:translateX(50px);
  }
  to{
    opacity:1;
    transform:none;
  }
}
@keyframes _fwjws_slide-from-left{
  0%{
    opacity:0;
    transform:translateX(-50px);
  }
  to{
    opacity:1;
    transform:none;
  }
}
.edit-site-sidebar__screen-wrapper{
  animation-duration:.14s;
  animation-timing-function:ease-in-out;
  display:flex;
  flex-direction:column;
  height:100%;
  max-height:100%;
  overflow-x:auto;
  padding:0 12px;
  scrollbar-color:#0000 #0000;
  scrollbar-gutter:stable both-edges;
  scrollbar-gutter:stable;
  scrollbar-width:thin;
  will-change:transform;
  will-change:transform, opacity;
}
.edit-site-sidebar__screen-wrapper::-webkit-scrollbar{
  height:12px;
  width:12px;
}
.edit-site-sidebar__screen-wrapper::-webkit-scrollbar-track{
  background-color:initial;
}
.edit-site-sidebar__screen-wrapper::-webkit-scrollbar-thumb{
  background-clip:padding-box;
  background-color:initial;
  border:3px solid #0000;
  border-radius:8px;
}
.edit-site-sidebar__screen-wrapper:focus-within::-webkit-scrollbar-thumb,.edit-site-sidebar__screen-wrapper:focus::-webkit-scrollbar-thumb,.edit-site-sidebar__screen-wrapper:hover::-webkit-scrollbar-thumb{
  background-color:#757575;
}
.edit-site-sidebar__screen-wrapper:focus,.edit-site-sidebar__screen-wrapper:focus-within,.edit-site-sidebar__screen-wrapper:hover{
  scrollbar-color:#757575 #0000;
}
@media (hover:none){
  .edit-site-sidebar__screen-wrapper{
    scrollbar-color:#757575 #0000;
  }
}
@media (prefers-reduced-motion:reduce){
  .edit-site-sidebar__screen-wrapper{
    animation-duration:0s;
  }
}
.edit-site-sidebar__screen-wrapper.slide-from-left{
  animation-name:_fwjws_slide-from-left;
}
.edit-site-sidebar__screen-wrapper.slide-from-right{
  animation-name:_fwjws_slide-from-right;
}

.edit-site-site-hub{
  align-items:center;
  display:flex;
  gap:8px;
  height:60px;
  justify-content:space-between;
  margin-right:12px;
}

.edit-site-site-hub__actions{
  flex-shrink:0;
}

.edit-site-site-hub__view-mode-toggle-container{
  flex-shrink:0;
  height:60px;
  width:60px;
}
.edit-site-site-hub__view-mode-toggle-container.has-transparent-background .edit-site-layout__view-mode-toggle-icon{
  background:#0000;
}

.edit-site-site-hub__title .components-button{
  color:#e0e0e0;
  display:block;
  flex-grow:1;
  font-size:15px;
  font-weight:500;
  margin-left:-4px;
  overflow:hidden;
  padding-right:16px;
  position:relative;
  text-decoration:none;
  text-overflow:ellipsis;
  white-space:nowrap;
}
.edit-site-site-hub__title .components-button:active,.edit-site-site-hub__title .components-button:focus,.edit-site-site-hub__title .components-button:hover{
  color:#e0e0e0;
}
.edit-site-site-hub__title .components-button:focus{
  box-shadow:none;
  outline:none;
}
.edit-site-site-hub__title .components-button:focus-visible{
  box-shadow:0 0 0 var(--wp-admin-border-width-focus) #1e1e1e, 0 0 0 calc(var(--wp-admin-border-width-focus)*2) var(--wp-admin-theme-color);
  outline:2px solid #0000;
  outline-offset:2px;
}
.edit-site-site-hub__title .components-button:after{
  content:"↗";
  font-weight:400;
  opacity:0;
  position:absolute;
  right:0;
}
@media not (prefers-reduced-motion){
  .edit-site-site-hub__title .components-button:after{
    transition:opacity .1s linear;
  }
}
.edit-site-site-hub__title .components-button:active:after,.edit-site-site-hub__title .components-button:focus:after,.edit-site-site-hub__title .components-button:hover:after{
  opacity:1;
}

.edit-site-site-hub_toggle-command-center{
  color:#e0e0e0;
}
.edit-site-site-hub_toggle-command-center:active svg,.edit-site-site-hub_toggle-command-center:hover svg{
  fill:#f0f0f0;
}

.edit-site-site-icon__icon{
  fill:currentColor;
  height:100%;
  width:100%;
}
.edit-site-layout.is-full-canvas .edit-site-site-icon__icon{
  padding:12px;
}

.edit-site-site-icon__image{
  aspect-ratio:1/1;
  background:#333;
  height:100%;
  object-fit:cover;
  width:100%;
}
.edit-site-layout.is-full-canvas .edit-site-site-icon__image{
  border-radius:0;
}

.edit-site-editor__view-mode-toggle button:focus{
  position:relative;
}
.edit-site-editor__view-mode-toggle button:focus:before{
  bottom:0;
  box-shadow:inset 0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color), inset 0 0 0 calc(1px + var(--wp-admin-border-width-focus)) #fff;
  content:"";
  display:block;
  left:0;
  position:absolute;
  right:0;
  top:0;
  z-index:1;
}

.edit-site-editor-canvas-container{
  background-color:#ddd;
  height:100%;
}
.edit-site-editor-canvas-container iframe{
  display:block;
  height:100%;
  width:100%;
}
.edit-site-layout.is-full-canvas .edit-site-editor-canvas-container{
  padding:24px 24px 0;
}

.edit-site-editor-canvas-container__section{
  background:#fff;
  border-radius:8px;
  bottom:0;
  left:0;
  overflow:hidden;
  position:absolute;
  right:0;
  top:0;
}
@media not (prefers-reduced-motion){
  .edit-site-editor-canvas-container__section{
    transition:all .3s;
  }
}

.edit-site-editor-canvas-container__close-button{
  background:#fff;
  position:absolute;
  right:8px;
  top:8px;
  z-index:2;
}

.edit-site-post-list__featured-image{
  height:100%;
  object-fit:cover;
  width:100%;
}

.edit-site-post-list__featured-image-wrapper{
  border-radius:4px;
  height:100%;
  width:100%;
}
.edit-site-post-list__featured-image-wrapper.is-layout-table .edit-site-post-list__featured-image-button,.edit-site-post-list__featured-image-wrapper.is-layout-table:not(:has(.edit-site-post-list__featured-image-button)){
  background-color:#f0f0f0;
  border-radius:4px;
  display:block;
  flex-grow:0 !important;
  height:32px;
  overflow:hidden;
  position:relative;
  width:32px;
}
.edit-site-post-list__featured-image-wrapper.is-layout-table .edit-site-post-list__featured-image-button:after,.edit-site-post-list__featured-image-wrapper.is-layout-table:not(:has(.edit-site-post-list__featured-image-button)):after{
  border-radius:4px;
  box-shadow:inset 0 0 0 1px #0000001a;
  content:"";
  height:100%;
  left:0;
  position:absolute;
  top:0;
  width:100%;
}

.edit-site-post-list__featured-image-button{
  background-color:unset;
  border:none;
  border-radius:4px;
  box-shadow:none;
  box-sizing:border-box;
  cursor:pointer;
  height:100%;
  overflow:hidden;
  padding:0;
  width:100%;
}
.edit-site-post-list__featured-image-button:focus-visible{
  box-shadow:0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color);
  outline:2px solid #0000;
}

.dataviews-view-grid__card.is-selected .edit-site-post-list__featured-image-button:after{
  background:rgba(var(--wp-admin-theme-color--rgb), .04);
  box-shadow:inset 0 0 0 var(--wp-admin-border-width-focus) var(--wp-admin-theme-color);
}

.edit-site-post-list__status-icon{
  height:24px;
  width:24px;
}
.edit-site-post-list__status-icon svg{
  fill:currentColor;
  margin-left:-4px;
}

.edit-site-resizable-frame__inner{
  position:relative;
}
body:has(.edit-site-resizable-frame__inner.is-resizing){
  cursor:col-resize;
  user-select:none;
  -webkit-user-select:none;
}

.edit-site-resizable-frame__inner.is-resizing:before{
  content:"";
  inset:0;
  position:absolute;
  z-index:1;
}

.edit-site-resizable-frame__inner-content{
  inset:0;
  position:absolute;
  z-index:0;
}

.edit-site-resizable-frame__handle{
  align-items:center;
  background-color:#75757566;
  border:0;
  border-radius:4px;
  cursor:col-resize;
  display:flex;
  height:64px;
  justify-content:flex-end;
  padding:0;
  position:absolute;
  top:calc(50% - 32px);
  width:4px;
  z-index:100;
}
.edit-site-resizable-frame__handle:before{
  content:"";
  height:100%;
  left:100%;
  position:absolute;
  width:32px;
}
.edit-site-resizable-frame__handle:after{
  content:"";
  height:100%;
  position:absolute;
  right:100%;
  width:32px;
}
.edit-site-resizable-frame__handle:focus-visible{
  outline:2px solid #0000;
}
.edit-site-resizable-frame__handle.is-resizing,.edit-site-resizable-frame__handle:focus,.edit-site-resizable-frame__handle:hover{
  background-color:var(--wp-admin-theme-color);
}

body.admin-color-light{
  --wp-admin-theme-color:#0085ba;
  --wp-admin-theme-color--rgb:0, 133, 186;
  --wp-admin-theme-color-darker-10:#0073a1;
  --wp-admin-theme-color-darker-10--rgb:0, 115, 161;
  --wp-admin-theme-color-darker-20:#006187;
  --wp-admin-theme-color-darker-20--rgb:0, 97, 135;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-light{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-modern{
  --wp-admin-theme-color:#3858e9;
  --wp-admin-theme-color--rgb:56, 88, 233;
  --wp-admin-theme-color-darker-10:#2145e6;
  --wp-admin-theme-color-darker-10--rgb:33, 69, 230;
  --wp-admin-theme-color-darker-20:#183ad6;
  --wp-admin-theme-color-darker-20--rgb:24, 58, 214;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-modern{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-blue{
  --wp-admin-theme-color:#096484;
  --wp-admin-theme-color--rgb:9, 100, 132;
  --wp-admin-theme-color-darker-10:#07526c;
  --wp-admin-theme-color-darker-10--rgb:7, 82, 108;
  --wp-admin-theme-color-darker-20:#064054;
  --wp-admin-theme-color-darker-20--rgb:6, 64, 84;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-blue{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-coffee{
  --wp-admin-theme-color:#46403c;
  --wp-admin-theme-color--rgb:70, 64, 60;
  --wp-admin-theme-color-darker-10:#383330;
  --wp-admin-theme-color-darker-10--rgb:56, 51, 48;
  --wp-admin-theme-color-darker-20:#2b2724;
  --wp-admin-theme-color-darker-20--rgb:43, 39, 36;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-coffee{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-ectoplasm{
  --wp-admin-theme-color:#523f6d;
  --wp-admin-theme-color--rgb:82, 63, 109;
  --wp-admin-theme-color-darker-10:#46365d;
  --wp-admin-theme-color-darker-10--rgb:70, 54, 93;
  --wp-admin-theme-color-darker-20:#3a2c4d;
  --wp-admin-theme-color-darker-20--rgb:58, 44, 77;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-ectoplasm{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-midnight{
  --wp-admin-theme-color:#e14d43;
  --wp-admin-theme-color--rgb:225, 77, 67;
  --wp-admin-theme-color-darker-10:#dd382d;
  --wp-admin-theme-color-darker-10--rgb:221, 56, 45;
  --wp-admin-theme-color-darker-20:#d02c21;
  --wp-admin-theme-color-darker-20--rgb:208, 44, 33;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-midnight{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-ocean{
  --wp-admin-theme-color:#627c83;
  --wp-admin-theme-color--rgb:98, 124, 131;
  --wp-admin-theme-color-darker-10:#576e74;
  --wp-admin-theme-color-darker-10--rgb:87, 110, 116;
  --wp-admin-theme-color-darker-20:#4c6066;
  --wp-admin-theme-color-darker-20--rgb:76, 96, 102;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-ocean{
    --wp-admin-border-width-focus:1.5px;
  }
}

body.admin-color-sunrise{
  --wp-admin-theme-color:#dd823b;
  --wp-admin-theme-color--rgb:221, 130, 59;
  --wp-admin-theme-color-darker-10:#d97426;
  --wp-admin-theme-color-darker-10--rgb:217, 116, 38;
  --wp-admin-theme-color-darker-20:#c36922;
  --wp-admin-theme-color-darker-20--rgb:195, 105, 34;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  body.admin-color-sunrise{
    --wp-admin-border-width-focus:1.5px;
  }
}

#adminmenumain,#wpadminbar{
  display:none;
}

#wpcontent{
  margin-left:0;
}

body.js #wpbody{
  padding-top:0;
}

body{
  background:#fff;
}
body #wpcontent{
  padding-left:0;
}
body #wpbody-content{
  padding-bottom:0;
}
body #wpbody-content>div:not(#gutenberg-posts-dashboard):not(#screen-meta),body #wpfooter{
  display:none;
}
body .a11y-speak-region{
  left:-1px;
  top:-1px;
}
body ul#adminmenu a.wp-has-current-submenu:after,body ul#adminmenu>li.current>a.current:after{
  border-right-color:#fff;
}
body .media-frame select.attachment-filters:last-of-type{
  max-width:100%;
  width:auto;
}

#gutenberg-posts-dashboard{
  box-sizing:border-box;
  height:100vh;
}
#gutenberg-posts-dashboard *,#gutenberg-posts-dashboard :after,#gutenberg-posts-dashboard :before{
  box-sizing:inherit;
}
@media (min-width:600px){
  #gutenberg-posts-dashboard{
    bottom:0;
    left:0;
    min-height:100vh;
    position:fixed;
    right:0;
    top:0;
  }
}
.no-js #gutenberg-posts-dashboard{
  min-height:0;
  position:static;
}
#gutenberg-posts-dashboard .components-editor-notices__snackbar{
  bottom:16px;
  padding-left:16px;
  padding-right:16px;
  position:fixed;
  right:0;
}